Subscriptions
Subscriptions
GetSubscription
Returns the subscription by id
Request
GET /api/manage/v1/Subscriptions/{id}
Parameters
| Name | Type | Value | Notes |
|---|---|---|---|
| *id | string | Identifier of subscription |
Responses
| Status Code | Description | Samples |
|---|---|---|
| 200 | Succesfully returned |
|
| 400 | The request is wrong |
|
| 403 | You don't have permissions for the operation |
|
| 404 | Subscription is not found |
|
| 500 | Try again, if error still here - text our support |
GetSubscriptions
Returns a list of all subscriptions of current user
Request
GET /api/manage/v1/Subscriptions[?skip&take]
Parameters
| Name | Type | Value | Notes |
|---|---|---|---|
| skip | integer | 0 | Variable for pagination, defautl value is 0 |
| take | integer | 10 | Variable for pagination, default value is 10 |
Responses
| Status Code | Description | Samples |
|---|---|---|
| 200 | Succesfully returned |
|
| 400 | unrealistic skip 'n take provided |
RenameSubscription
Rename subscription
Request
PUT /api/manage/v1/Subscriptions/{subscriptionId}/rename
Parameters
| Name | Type | Value | Notes |
|---|---|---|---|
| *subscriptionId | string | id |
|
| *body | rename VM |
Responses
| Status Code | Description | Samples |
|---|---|---|
| 200 | Successfully renamed |
|
| 400 | Request is wrong |
|
| 402 | Subscription is outdated |
|
| 403 | Not enough permissions |
|
| 404 | There is no subscription with such id (or user have no permission) |
UpdatePreviewType
Update subscription's preview type
Request
PUT /api/manage/v1/Subscriptions/{subscriptionId}/PreviewType
Parameters
| Name | Type | Value | Notes |
|---|---|---|---|
| *subscriptionId | string | id |
|
| *body | update VM |
Responses
| Status Code | Description | Samples |
|---|---|---|
| 200 | Successfully updated |
|
| 400 | Request is wrong |
|
| 402 | Subscription is outdated |
|
| 403 | Not enough permissions |
|
| 404 | There is no subscription with such id (or user have no permission) |
UpdateLocale
Update subscription's default locale
Request
PUT /api/manage/v1/Subscriptions/{subscriptionId}/Locale
Parameters
| Name | Type | Value | Notes |
|---|---|---|---|
| *subscriptionId | string | id |
|
| *body | update VM |
Responses
| Status Code | Description | Samples |
|---|---|---|
| 200 | Successfully renamed |
|
| 400 | Request is wrong |
|
| 402 | Subscription is outdated |
|
| 403 | Not enough permissions |
|
| 404 | There is no subscription with such id (or user have no permission) |
UpdateDefaultPermissions
Change subscription's default permissions for new entities
Request
PUT /api/manage/v1/Subscriptions/{subscriptionId}/defaultPermissions
Parameters
| Name | Type | Value | Notes |
|---|---|---|---|
| *subscriptionId | string | id |
|
| *body | update default permissions VM |
Responses
| Status Code | Description | Samples |
|---|---|---|
| 200 | Successfully changed |
|
| 400 | Request is wrong |
|
| 402 | Subscription is outdated |
|
| 403 | Not enough permissions |
|
| 404 | There is no subscription with such id |
GetDefaultPermissions
Get subscription's default permissions for new entities
Request
GET /api/manage/v1/Subscriptions/{subscriptionId}/defaultPermissions
Parameters
| Name | Type | Value | Notes |
|---|---|---|---|
| *subscriptionId | string | id |
Responses
| Status Code | Description | Samples |
|---|---|---|
| 200 | Successfully returned |
|
| 400 | Request is wrong |
|
| 402 | Subscription is outdated |
|
| 403 | Not enough permissions |
|
| 404 | There is no subscription with such id |
GetPermissions
Get permissions for a subscription by id
Request
GET /api/manage/v1/Subscriptions/{id}/permissions
Parameters
| Name | Type | Value | Notes |
|---|---|---|---|
| *id | string |
Responses
| Status Code | Description | Samples |
|---|---|---|
| 200 | Succesfully returned |
|
| 400 | Request is wrong |
|
| 402 | Subscription is outdated |
|
| 403 | Not enough permissions |
|
| 404 | There is no subscription with such id |
UpdatePermissions
Update permissions
Request
POST /api/manage/v1/Subscriptions/{id}/permissions
Parameters
| Name | Type | Value | Notes |
|---|---|---|---|
| *id | string | ||
| body |
Responses
| Status Code | Description | Samples |
|---|---|---|
| 204 | Succesfully updated |
|
| 400 | Request is wrong |
|
| 402 | Subscription is outdated |
|
| 403 | Not enough permissions |
|
| 404 | There is no subscription with such id |
GetMyPermissions
Get user's permissions for a subscription by id
Request
GET /api/manage/v1/Subscriptions/{subId}/mypermissions
Parameters
| Name | Type | Value | Notes |
|---|---|---|---|
| *subId | string | subscription id |
Responses
| Status Code | Description | Samples |
|---|---|---|
| 200 | Succesfully returned |
UpdateSubscriptionDomains
Update subscription's allowed domains
Request
PUT /api/manage/v1/Subscriptions/{subscriptionId}/Domains
Parameters
| Name | Type | Value | Notes |
|---|---|---|---|
| *subscriptionId | string | id |
|
| *body | update VM |
Responses
| Status Code | Description | Samples |
|---|---|---|
| 200 | Successfully renamed |
|
| 400 | Request is wrong |
|
| 402 | Subscription is outdated |
|
| 403 | Not enough permissions |
|
| 404 | There is no subscription with such id (or user have no permission) |
Definitions
SubscriptionVM
| Name | Type | Notes |
|---|---|---|
| id | string | |
| name | string | |
| locale | string | |
| current |
|
|
| old |
|
|
| templatesFolder |
|
|
| reportsFolder |
|
|
| exportsFolder |
|
|
| previewType |
|
|
| tags | array | |
| domains | array | |
| $t | string |
SubscriptionPeriodVM
| Name | Type | Notes |
|---|---|---|
| startTime | string (date-time) | |
| endTime | string (date-time) | |
| plan |
|
|
| $t | string |
SubscriptionPlanVM
| Name | Type | Notes |
|---|---|---|
| id | string | |
| isActive | boolean | |
| displayName | string | |
| timePeriodType |
|
|
| timePeriod | integer (int32) | |
| readonlyTimeLimitType |
|
|
| readonlyTimeLimit | integer (int32) | |
| templatesSpaceLimit | integer (int64) | |
| reportsSpaceLimit | integer (int64) | |
| exportsSpaceLimit | integer (int64) | |
| fontsSpaceLimit | integer (int64) | |
| fileUploadSizeLimit | integer (int64) | |
| dataSourceLimit | integer (int32) | |
| maxUsersCount | integer (int32) | |
| groupLimit | integer (int32) | |
| onlineDesigner | boolean | |
| isDemo | boolean | |
| urlToBuy | string | |
| unlimitedPage | boolean | |
| pageLimit | integer (int32) | |
| tasks |
|
|
| $t | string |
TimePeriodType
Enum Values
SecondMinute
Hour
Day
Week
Month
Year
TaskSettingsVM
| Name | Type | Notes |
|---|---|---|
| isSchedulerEnabled | boolean | |
| prepare | boolean | |
| exportTemplate | boolean | |
| exportReport | boolean | |
| sendViaEmail | boolean | |
| uploadToFTP | boolean | |
| uploadToS3 | boolean | |
| uploadToTelegram | boolean | |
| sendViaWebhook | boolean | |
| fetchData | boolean | |
| thumbnailReport | boolean | |
| thumbnailTemplate | boolean | |
| $t | string |
SubscriptionFolder
| Name | Type | Notes |
|---|---|---|
| folderId | string | |
| bytesUsed | integer (int64) |
PreviewType
ProblemDetails
| Name | Type | Notes |
|---|---|---|
| type | string | |
| title | string | |
| status | integer (int32) | |
| detail | string | |
| instance | string |
SubscriptionsVM
| Name | Type | Notes |
|---|---|---|
| subscriptions |
|
|
| count | integer (int64) | |
| skip | integer (int32) | |
| take | integer (int32) | |
| $t | string |
RenameSubscriptionVM
| Name | Type | Notes |
|---|---|---|
| name | string | |
| $t | string |
UpdateSubscriptionPreviewTypeVM
| Name | Type | Notes |
|---|---|---|
| previewType |
|
|
| $t | string |
UpdateSubscriptionLocaleVM
| Name | Type | Notes |
|---|---|---|
| locale | string | |
| $t | string |
UpdateDefaultPermissionsVM
| Name | Type | Notes |
|---|---|---|
| filePermissions |
|
|
| groupPermissions |
|
|
| dataSourcePermissions |
|
|
| taskPermissions |
|
|
| fontPermissions |
|
|
| $t | string |
UpdateFilePermissionsVM
| Name | Type | Notes |
|---|---|---|
| newPermissions |
|
|
| administrate |
|
|
| $t | string |
FilePermissionsCRUDVM
| Name | Type | Notes |
|---|---|---|
| ownerId | string | |
| owner |
|
|
| groups | object | |
| other |
|
|
| anon |
|
|
| $t | string |
FilePermissionCRUDVM
| Name | Type | Notes |
|---|---|---|
| create |
|
|
| delete |
|
|
| execute |
|
|
| get |
|
|
| update |
|
|
| administrate |
|
|
| $t | string |
FileCreate
FileDelete
FileExecute
FileGet
FileUpdate
FileAdministrate
UpdateGroupPermissionsVM
| Name | Type | Notes |
|---|---|---|
| newPermissions |
|
|
| administrate |
|
|
| $t | string |
GroupPermissionsCRUDVM
| Name | Type | Notes |
|---|---|---|
| ownerId | string | |
| owner |
|
|
| groups | object | |
| other |
|
|
| anon |
|
|
| $t | string |
GroupPermissionCRUDVM
| Name | Type | Notes |
|---|---|---|
| create |
|
|
| delete |
|
|
| execute |
|
|
| get |
|
|
| update |
|
|
| administrate |
|
|
| $t | string |
GroupCreate
GroupDelete
GroupExecute
GroupGet
GroupUpdate
GroupAdministrate
UpdateDataSourcePermissionsVM
| Name | Type | Notes |
|---|---|---|
| newPermissions |
|
|
| administrate |
|
|
| $t | string |
DataSourcePermissionsCRUDVM
| Name | Type | Notes |
|---|---|---|
| ownerId | string | |
| owner |
|
|
| groups | object | |
| other |
|
|
| anon |
|
|
| $t | string |
DataSourcePermissionCRUDVM
| Name | Type | Notes |
|---|---|---|
| create |
|
|
| delete |
|
|
| execute |
|
|
| get |
|
|
| update |
|
|
| administrate |
|
|
| $t | string |
DataSourceCreate
DataSourceDelete
DataSourceExecute
DataSourceGet
DataSourceUpdate
DataSourceAdministrate
UpdateTaskPermissionsVM
| Name | Type | Notes |
|---|---|---|
| administrate |
|
|
| newPermissions |
|
|
| $t | string |
TaskAdministrate
TaskPermissionsCRUDVM
| Name | Type | Notes |
|---|---|---|
| ownerId | string | |
| owner |
|
|
| groups | object | |
| other |
|
|
| anon |
|
|
| $t | string |
TaskPermissionCRUDVM
| Name | Type | Notes |
|---|---|---|
| create |
|
|
| delete |
|
|
| execute |
|
|
| get |
|
|
| update |
|
|
| administrate |
|
|
| $t | string |
TaskCreate
TaskDelete
TaskExecute
TaskGet
TaskUpdate
UpdateUserFontPermissionsVM
| Name | Type | Notes |
|---|---|---|
| newPermissions |
|
|
| administrate |
|
|
| $t | string |
UserFontPermissionsCRUDVM
| Name | Type | Notes |
|---|---|---|
| ownerId | string | |
| owner |
|
|
| groups | object | |
| other |
|
|
| anon |
|
|
| $t | string |
UserFontPermissionCRUDVM
| Name | Type | Notes |
|---|---|---|
| create |
|
|
| delete |
|
|
| execute |
|
|
| get |
|
|
| update |
|
|
| administrate |
|
|
| $t | string |
FontCreate
FontDelete
FontExecute
FontGet
FontUpdate
FontAdministrate
DefaultPermissionsVM
| Name | Type | Notes |
|---|---|---|
| filePermissions |
|
|
| dataSourcePermissions |
|
|
| groupPermissions |
|
|
| taskPermissions |
|
|
| fontPermissions |
|
|
| $t | string |
SubscriptionPermissionsVM
| Name | Type | Notes |
|---|---|---|
| permissions |
|
|
| $t | string |
SubscriptionPermissionsCRUDVM
| Name | Type | Notes |
|---|---|---|
| ownerId | string | |
| owner |
|
|
| groups | object | |
| other |
|
|
| anon |
|
|
| $t | string |
SubscriptionPermissionCRUDVM
| Name | Type | Notes |
|---|---|---|
| create |
|
|
| delete |
|
|
| execute |
|
|
| get |
|
|
| update |
|
|
| administrate |
|
|
| $t | string |
SubscriptionCreate
SubscriptionDelete
SubscriptionExecute
SubscriptionGet
SubscriptionUpdate
SubscriptionAdministrate
UpdateSubscriptionPermissionsVM
| Name | Type | Notes |
|---|---|---|
| newPermissions |
|
|
| administrate |
|
|
| $t | string |
MyPermissionsVM
| Name | Type | Notes |
|---|---|---|
| subscription |
|
|
| files |
|
|
| datasources |
|
|
| groups |
|
|
| tasks |
|
|
| $t | string |
UpdateSubscriptionDomainsVM
| Name | Type | Notes |
|---|---|---|
| domains | array |